Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(865)

Unified Diff: sql/connection_memory_dump_provider.h

Issue 2545173002: [tracing] Remove MemoryAllocatorDump::process_memory_dump (Closed)
Patch Set: Fix include. Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sql/connection.cc ('k') | sql/connection_memory_dump_provider.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sql/connection_memory_dump_provider.h
diff --git a/sql/connection_memory_dump_provider.h b/sql/connection_memory_dump_provider.h
index ca24a21aeb37fc62235556a82a1f4e7a200a5997..73b2bd82d2354d2bcd338a40a9c4398534906271 100644
--- a/sql/connection_memory_dump_provider.h
+++ b/sql/connection_memory_dump_provider.h
@@ -9,11 +9,16 @@
#include "base/macros.h"
#include "base/synchronization/lock.h"
-#include "base/trace_event/memory_allocator_dump.h"
#include "base/trace_event/memory_dump_provider.h"
struct sqlite3;
+namespace base {
+namespace trace_event {
+class ProcessMemoryDump;
+}
+}
+
namespace sql {
class ConnectionMemoryDumpProvider
@@ -29,9 +34,10 @@ class ConnectionMemoryDumpProvider
const base::trace_event::MemoryDumpArgs& args,
base::trace_event::ProcessMemoryDump* process_memory_dump) override;
// Reports memory usage into provided memory dump.
// Called by sql::Connection when its owner asks it to report memory usage.
- bool ReportMemoryUsage(base::trace_event::MemoryAllocatorDump* mad);
+ bool ReportMemoryUsage(base::trace_event::ProcessMemoryDump* pmd,
+ const std::string& dump_name);
private:
bool GetDbMemoryUsage(int* cache_size,
« no previous file with comments | « sql/connection.cc ('k') | sql/connection_memory_dump_provider.cc » ('j') | no next file with comments »
@@ -29,9 +34,10 @@ class ConnectionMemoryDumpProvider
const base::trace_event::MemoryDumpArgs& args,
base::trace_event::ProcessMemoryDump* process_memory_dump) override;
- // Reports memory usage into provided memory dump.
+ // Reports memory usage into provided memory dump with the given |dump_name|.
// Called by sql::Connection when its owner asks it to report memory usage.

Powered by Google App Engine
This is Rietveld 408576698